"""
Author : Abdullah Al Masud\n
email : abdullahalmasud.buet@gmail.com\n
LICENSE : MIT License
"""


class CutoffError(Exception):
    pass


class FilterTypeError(Exception):
    pass


class InputVariableError(Exception):
    pass


class WordLengthError(Exception):
    pass


class InvalidBins(Exception):
    pass


class DataLabelMismatchError(Exception):
    pass


class SplitMethodError(Exception):
    pass
